### Personal Collection of Reusable Python Tools
This is a simple set of tools for Python applications. While some of them may seem useless or unnecessary, they can actually help keep your code shorter.

### Future changes (Before beta):

- Removal of all items from init, to make everything more accessable. [ ]
- Better naming conventions for both modules and functions. [ ]
- Addition of more custom math libraries. [ ]
- Creation of a few template classes to make more projects more accessable. [ ]